# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DteIPv4Adres import DteIPv4Adres, DteIPv4AdresWaarden
from ...Datatypes.KlAudioTransportType import KlAudioTransportType
from ...Datatypes.KlIntercomServerMerk import KlIntercomServerMerk
from ...Datatypes.KlIntercomServerModelnaam import KlIntercomServerModelnaam
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class IntercomServer(NaampadObject, PuntGeometrie):
    """Centrale module - inclusief configuratiesoftware - die de intercomtoestellen koppelt, bv. per tunnel of per complex, en een gateway opzet naar de centrale systemen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SoftwareToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Meetmicrofoon', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Omvormer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Rack', direction='i')  # i = direction: incoming

        self._dnsNaam = OTLAttribuut(field=StringField,
                                     naam='dnsNaam',
                                     label='DNS naam',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer.dnsNaam',
                                     definition='De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be.',
                                     owner=self)

        self._ipAdres = OTLAttribuut(field=DteIPv4Adres,
                                     naam='ipAdres',
                                     label='IP-adres',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer.ipAdres',
                                     definition='Het IP-adres van de intercomserver.',
                                     owner=self)

        self._merk = OTLAttribuut(field=KlIntercomServerMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer.merk',
                                  definition='Het merk van de intercomserver.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlIntercomServerModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer.modelnaam',
                                       definition='De modelnaam van de intercomserver.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer.technischeFiche',
                                             definition='De technische fiche van de intercomserver.',
                                             owner=self)

        self._transportType = OTLAttribuut(field=KlAudioTransportType,
                                           naam='transportType',
                                           label='transport type',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomServer.transportType',
                                           definition='Geeft aan op welke manier het audiosignaal wordt getransporteerd door het toestel.',
                                           owner=self)

    @property
    def dnsNaam(self) -> str:
        """De DNSNaam (ook "volledige domein naam" genoemd ) is een unieke naam binnen het Domain Name System (DNS), het naamgevingssysteem waarmee computers, webservers, diensten en toepassing op een unieke manier kunnen worden geïdentificeerd. Deze bevat zowel de hostname en de top level domein naam bv. 120c8-ar1.belfa.be."""
        return self._dnsNaam.get_waarde()

    @dnsNaam.setter
    def dnsNaam(self, value):
        self._dnsNaam.set_waarde(value, owner=self)

    @property
    def ipAdres(self) -> DteIPv4AdresWaarden:
        """Het IP-adres van de intercomserver."""
        return self._ipAdres.get_waarde()

    @ipAdres.setter
    def ipAdres(self, value):
        self._ipAdres.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de intercomserver."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de intercomserver."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de intercomserver."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def transportType(self) -> str:
        """Geeft aan op welke manier het audiosignaal wordt getransporteerd door het toestel."""
        return self._transportType.get_waarde()

    @transportType.setter
    def transportType(self, value):
        self._transportType.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.NaampadObject import NaampadObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class DynBordGroep(NaampadObject, PuntGeometrie):
    """Een groep voor het groeperen van Dynamische borden: DynBordRSS, DynBordPK, DynBordVMS en DynBordRVMS. Deze groep is op zichzelf geen fysiek object,maar een verzameling van fysieke objecten."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DynBordGroep'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftAanvullendeGeometrie', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderdoorboring', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aardingskabel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Beschermbuis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordPK', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordRSS', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordRVMS', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordVMS', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelmof', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TechnischePut', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegkantkast', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlRegelbaarTegengewichtMateriaal(KeuzelijstField):
    """De mogelijke materialen als regelbaar tegengewicht."""
    naam = 'KlRegelbaarTegengewichtMateriaal'
    label = 'Regelbaar tegengewicht materiaal'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlRegelbaarTegengewichtMateriaal'
    definition = 'De mogelijke materialen als regelbaar tegengewicht.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlRegelbaarTegengewichtMateriaal'
    options = {
        'andere': KeuzelijstWaarde(invulwaarde='andere',
                                   label='andere',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRegelbaarTegengewichtMateriaal/andere'),
        'beton': KeuzelijstWaarde(invulwaarde='beton',
                                  label='beton',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRegelbaarTegengewichtMateriaal/beton'),
        'gietijzer': KeuzelijstWaarde(invulwaarde='gietijzer',
                                      label='gietijzer',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRegelbaarTegengewichtMateriaal/gietijzer'),
        'lood': KeuzelijstWaarde(invulwaarde='lood',
                                 label='lood',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRegelbaarTegengewichtMateriaal/lood'),
        'staal': KeuzelijstWaarde(invulwaarde='staal',
                                  label='staal',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRegelbaarTegengewichtMateriaal/staal'),
        'vloeistof': KeuzelijstWaarde(invulwaarde='vloeistof',
                                      label='vloeistof',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlRegelbaarTegengewichtMateriaal/vloeistof')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod, ABC
from ...Datatypes.KlLEACKerendVermogen import KlLEACKerendVermogen
from ...Datatypes.KlLEACVoertuigOverhelling import KlLEACVoertuigOverhelling


# Generated with OTLClassCreator. To modify: extend, do not edit
class EigenschappenVoertuigkering(ABC):
    """Op deze abstracte worden attributen met betrekking tot voertuigkering bijgehouden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EigenschappenVoertuigkering'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._kerendVermogen = OTLAttribuut(field=KlLEACKerendVermogen,
                                            naam='kerendVermogen',
                                            label='kerend vermogen',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EigenschappenVoertuigkering.kerendVermogen',
                                            definition='Het vermogen van een voertuigkering om een doorbraak bij een bepaald type crash te voorkomen.',
                                            owner=self)

        self._voertuigOverhelling = OTLAttribuut(field=KlLEACVoertuigOverhelling,
                                                 naam='voertuigOverhelling',
                                                 label='voertuig overhelling',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#EigenschappenVoertuigkering.voertuigOverhelling',
                                                 definition="Naast het horizontaal verplaatsen van de veiligheidsafbakening bij een impact, kan een voertuig bij impact ook over de afbakening hellen. De maximale overhelling wordt op basis van foto's en video-opnames van de test bepaald.",
                                                 owner=self)

    @property
    def kerendVermogen(self) -> str:
        """Het vermogen van een voertuigkering om een doorbraak bij een bepaald type crash te voorkomen."""
        return self._kerendVermogen.get_waarde()

    @kerendVermogen.setter
    def kerendVermogen(self, value):
        self._kerendVermogen.set_waarde(value, owner=self)

    @property
    def voertuigOverhelling(self) -> str:
        """Naast het horizontaal verplaatsen van de veiligheidsafbakening bij een impact, kan een voertuig bij impact ook over de afbakening hellen. De maximale overhelling wordt op basis van foto's en video-opnames van de test bepaald."""
        return self._voertuigOverhelling.get_waarde()

    @voertuigOverhelling.setter
    def voertuigOverhelling(self, value):
        self._voertuigOverhelling.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlFiguratieType(KeuzelijstField):
    """Types van figuratiemarkering."""
    naam = 'KlFiguratieType'
    label = 'Figuratie type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlFiguratieType'
    definition = 'Types van figuratiemarkering.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlFiguratieType'
    options = {
        '2e-afslag-links-(5m)': KeuzelijstWaarde(invulwaarde='2e-afslag-links-(5m)',
                                                 label='2e afslag links (5m)',
                                                 status='ingebruik',
                                                 definitie='Pijl 2e afslag links (5m).',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/2e-afslag-links-(5m)'),
        '2e-afslag-links-(7.5m)': KeuzelijstWaarde(invulwaarde='2e-afslag-links-(7.5m)',
                                                   label='2e afslag links (7.5m)',
                                                   status='ingebruik',
                                                   definitie='Pijl 2e afslag links (7,5m)',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/2e-afslag-links-(7.5m)'),
        '2e-afslag-rechts-(5m)': KeuzelijstWaarde(invulwaarde='2e-afslag-rechts-(5m)',
                                                  label='2e afslag rechts (5m)',
                                                  status='ingebruik',
                                                  definitie='Pijl 2e afslag rechts (5m)',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/2e-afslag-rechts-(5m)'),
        '2e-afslag-rechts-(7.5m)': KeuzelijstWaarde(invulwaarde='2e-afslag-rechts-(7.5m)',
                                                    label='2e afslag rechts (7.5m)',
                                                    status='ingebruik',
                                                    definitie='Pijl 2e afslag rechts (7,5m)',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/2e-afslag-rechts-(7.5m)'),
        'BUS-(dwars-op-BOB)': KeuzelijstWaarde(invulwaarde='BUS-(dwars-op-BOB)',
                                               label='BUS (dwars op BOB)',
                                               status='ingebruik',
                                               definitie='Lettermarkering van bus (dwars op BOB)',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/BUS-(dwars-op-BOB)'),
        'BUS-(dwars-op-busstrook)': KeuzelijstWaarde(invulwaarde='BUS-(dwars-op-busstrook)',
                                                     label='BUS (dwars op busstrook)',
                                                     status='ingebruik',
                                                     definitie='Lettermarkering van bus (dwars op busstrook)',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/BUS-(dwars-op-busstrook)'),
        'BUS-(langs-op-BOB)': KeuzelijstWaarde(invulwaarde='BUS-(langs-op-BOB)',
                                               label='BUS (langs op BOB)',
                                               status='ingebruik',
                                               definitie='Lettermarkering van bus (langs op BOB)',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/BUS-(langs-op-BOB)'),
        'STOP': KeuzelijstWaarde(invulwaarde='STOP',
                                 label='STOP',
                                 status='ingebruik',
                                 definitie='Lettermarkering STOP',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/STOP'),
        'STOP-(smal)': KeuzelijstWaarde(invulwaarde='STOP-(smal)',
                                        label='STOP (smal)',
                                        status='ingebruik',
                                        definitie='Lettermarkering STOP (smal)',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/STOP-(smal)'),
        'TAXI-(dwars)': KeuzelijstWaarde(invulwaarde='TAXI-(dwars)',
                                         label='TAXI (dwars)',
                                         status='ingebruik',
                                         definitie='Lettermarkering van taxiplaats (dwars)',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/TAXI-(dwars)'),
        'TAXI-(langs)': KeuzelijstWaarde(invulwaarde='TAXI-(langs)',
                                         label='TAXI (langs)',
                                         status='ingebruik',
                                         definitie='Lettermarkering van taxiplaats (langs)',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/TAXI-(langs)'),
        'TRAM-(dwars)': KeuzelijstWaarde(invulwaarde='TRAM-(dwars)',
                                         label='TRAM (dwars)',
                                         status='ingebruik',
                                         definitie='Lettermarkering van tramhalte (dwars)',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/TRAM-(dwars)'),
        'TRAM-(langs)': KeuzelijstWaarde(invulwaarde='TRAM-(langs)',
                                         label='TRAM (langs)',
                                         status='ingebruik',
                                         definitie='Lettermarkering van tramhalte (langs)',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/TRAM-(langs)'),
        'autocar': KeuzelijstWaarde(invulwaarde='autocar',
                                    label='autocar',
                                    status='ingebruik',
                                    definitie='Symbool autocar.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/autocar'),
        'blauwe-zone-(parkeerschijf)': KeuzelijstWaarde(invulwaarde='blauwe-zone-(parkeerschijf)',
                                                        label='blauwe zone (parkeerschijf)',
                                                        status='ingebruik',
                                                        definitie='Verkeersbordmarkering blauwe zone (parkeerschijf).',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/blauwe-zone-(parkeerschijf)'),
        'bromfiets-groot': KeuzelijstWaarde(invulwaarde='bromfiets-groot',
                                            label='bromfiets groot',
                                            status='ingebruik',
                                            definitie='Symbool bromfiets groot.',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/bromfiets-groot'),
        'bromfiets-klein': KeuzelijstWaarde(invulwaarde='bromfiets-klein',
                                            label='bromfiets klein',
                                            status='ingebruik',
                                            definitie='Symbool bromfiets klein.',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/bromfiets-klein'),
        'bushalte-op-de-rijweg': KeuzelijstWaarde(invulwaarde='bushalte-op-de-rijweg',
                                                  label='bushalte op de rijweg',
                                                  status='ingebruik',
                                                  definitie='Lettermarkering bus zonder arcering.',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/bushalte-op-de-rijweg'),
        'elektrische-voertuigen-normaal': KeuzelijstWaarde(invulwaarde='elektrische-voertuigen-normaal',
                                                           label='elektrische voertuigen normaal',
                                                           status='ingebruik',
                                                           definitie='Symbool elektrische voertuigen normaal.',
                                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/elektrische-voertuigen-normaal'),
        'elektrische-voertuigen-vergroot': KeuzelijstWaarde(invulwaarde='elektrische-voertuigen-vergroot',
                                                            label='elektrische voertuigen vergroot',
                                                            status='ingebruik',
                                                            definitie='Symbool elektrische voertuigen vergroot.',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/elektrische-voertuigen-vergroot'),
        'elektrische-voertuigen-verkleind': KeuzelijstWaarde(invulwaarde='elektrische-voertuigen-verkleind',
                                                             label='elektrische voertuigen verkleind',
                                                             status='ingebruik',
                                                             definitie='Symbool elektrische voertuigen verkleind.',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/elektrische-voertuigen-verkleind'),
        'fietslogo-Groot': KeuzelijstWaarde(invulwaarde='fietslogo-Groot',
                                            label='fietslogo Groot',
                                            status='ingebruik',
                                            definitie='Logomarkering fiestslogo Groot.',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/fietslogo-Groot'),
        'fietslogo-Klein': KeuzelijstWaarde(invulwaarde='fietslogo-Klein',
                                            label='fietslogo Klein',
                                            status='ingebruik',
                                            definitie='Logomarkering fiestslogo Klein.',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/fietslogo-Klein'),
        'fietspadpijl-(klein---dubbele-fietspadpijl)': KeuzelijstWaarde(invulwaarde='fietspadpijl-(klein---dubbele-fietspadpijl)',
                                                                        label='fietspadpijl (klein - dubbele fietspadpijl)',
                                                                        status='ingebruik',
                                                                        definitie='Pijl Fietspadpijl (klein - dubbele fietspadpijl)',
                                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/fietspadpijl-(klein---dubbele-fietspadpijl)'),
        'fietspadpijl-(std)': KeuzelijstWaarde(invulwaarde='fietspadpijl-(std)',
                                               label='fietspadpijl (std)',
                                               status='ingebruik',
                                               definitie='Pijl Fietspadpijl (std)',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/fietspadpijl-(std)'),
        'fietsstraat-begin': KeuzelijstWaarde(invulwaarde='fietsstraat-begin',
                                              label='fietsstraat begin',
                                              status='ingebruik',
                                              definitie='Verkeersbord F111 dat het einde van de fietsstraat aanduidt.',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/fietsstraat-begin'),
        'fietsstraat-einde': KeuzelijstWaarde(invulwaarde='fietsstraat-einde',
                                              label='fietsstraat einde',
                                              status='ingebruik',
                                              definitie='Verkeersbord F113 dat het einde van de fietsstraat aanduidt.',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/fietsstraat-einde'),
        'fietsvoorsortering-Links': KeuzelijstWaarde(invulwaarde='fietsvoorsortering-Links',
                                                     label='fietsvoorsortering Links',
                                                     status='ingebruik',
                                                     definitie='Pijl Fietsvoorsortering Links',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/fietsvoorsortering-Links'),
        'groot': KeuzelijstWaarde(invulwaarde='groot',
                                  label='groot',
                                  status='ingebruik',
                                  definitie='Omgekeerde driehoek markering groot type.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/groot'),
        'groter-dan-22.75-m²': KeuzelijstWaarde(invulwaarde='groter-dan-22.75-m²',
                                                label='groter dan 22.75 m²',
                                                status='ingebruik',
                                                definitie='Lettermarkering bus met arcering.',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/groter-dan-22.75-m²'),
        'klein': KeuzelijstWaarde(invulwaarde='klein',
                                  label='klein',
                                  status='ingebruik',
                                  definitie='Omgekeerde driehoek markering klein type.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/klein'),
        'kleiner-dan-22.75-m²': KeuzelijstWaarde(invulwaarde='kleiner-dan-22.75-m²',
                                                 label='kleiner dan 22.75 m²',
                                                 status='ingebruik',
                                                 definitie='Lettermarkering bus met arcering.',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/kleiner-dan-22.75-m²'),
        'kruising-sporen': KeuzelijstWaarde(invulwaarde='kruising-sporen',
                                            label='kruising sporen',
                                            status='ingebruik',
                                            definitie='Aanduiding A49 kruising van een openbare weg door één of meer in de rijbaan aangelegde sporen.',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/kruising-sporen'),
        'links-(5m)': KeuzelijstWaarde(invulwaarde='links-(5m)',
                                       label='links (5m)',
                                       status='ingebruik',
                                       definitie='Pijl Links (5m)',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/links-(5m)'),
        'links-(7.5m)': KeuzelijstWaarde(invulwaarde='links-(7.5m)',
                                         label='links (7.5m)',
                                         status='ingebruik',
                                         definitie='Pijl Links (7,5m)',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/links-(7.5m)'),
        'links-+-Rechts-(5m)': KeuzelijstWaarde(invulwaarde='links-+-Rechts-(5m)',
                                                label='links + Rechts (5m)',
                                                status='ingebruik',
                                                definitie='Pijl Links + Rechts (5m)',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/links-+-Rechts-(5m)'),
        'links-+-Rechts-(7.5m)': KeuzelijstWaarde(invulwaarde='links-+-Rechts-(7.5m)',
                                                  label='links + Rechts (7.5m)',
                                                  status='ingebruik',
                                                  definitie='Pijl Links + Rechts (7,5m)',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/links-+-Rechts-(7.5m)'),
        'mindervaliden-logo-klein': KeuzelijstWaarde(invulwaarde='mindervaliden-logo-klein',
                                                     label='mindervaliden logo klein',
                                                     status='ingebruik',
                                                     definitie='Logomarkering Mindervaliden klein.',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/mindervaliden-logo-klein'),
        'mindervaliden-logo-normaal': KeuzelijstWaarde(invulwaarde='mindervaliden-logo-normaal',
                                                       label='mindervaliden logo normaal',
                                                       status='ingebruik',
                                                       definitie='Logomarkering Mindervaliden normaal.',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/mindervaliden-logo-normaal'),
        'mindervaliden-logo-vergroot': KeuzelijstWaarde(invulwaarde='mindervaliden-logo-vergroot',
                                                        label='mindervaliden logo vergroot',
                                                        status='ingebruik',
                                                        definitie='Logomarkering Mindervaliden vergroot.',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/mindervaliden-logo-vergroot'),
        'null': KeuzelijstWaarde(invulwaarde='null',
                                 label='null',
                                 status='ingebruik',
                                 definitie='Geen aanduiding.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/null'),
        'oversteekplaats-voor-voetgangers': KeuzelijstWaarde(invulwaarde='oversteekplaats-voor-voetgangers',
                                                             label='oversteekplaats voor voetgangers',
                                                             status='ingebruik',
                                                             definitie='Aanduiding A21 oversteekplaats voor voetgangers.',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/oversteekplaats-voor-voetgangers'),
        'parkeerverbod': KeuzelijstWaarde(invulwaarde='parkeerverbod',
                                          label='parkeerverbod',
                                          status='ingebruik',
                                          definitie='Verkeersbordmarkering parkeerverbod.',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/parkeerverbod'),
        'rechtdoor-(5m)': KeuzelijstWaarde(invulwaarde='rechtdoor-(5m)',
                                           label='rechtdoor (5m)',
                                           status='ingebruik',
                                           definitie='Pijl rechtdoor (5m)',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-(5m)'),
        'rechtdoor-+-Links-(5m)': KeuzelijstWaarde(invulwaarde='rechtdoor-+-Links-(5m)',
                                                   label='rechtdoor + Links (5m)',
                                                   status='ingebruik',
                                                   definitie='Pijl Rechtdoor + Links (5m)',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-+-Links-(5m)'),
        'rechtdoor-+-Links-(7.5m)': KeuzelijstWaarde(invulwaarde='rechtdoor-+-Links-(7.5m)',
                                                     label='rechtdoor + Links (7.5m)',
                                                     status='ingebruik',
                                                     definitie='Pijl Rechtdoor + Links (7,5m)',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-+-Links-(7.5m)'),
        'rechtdoor-+-Links-+-Rechts-(5m)': KeuzelijstWaarde(invulwaarde='rechtdoor-+-Links-+-Rechts-(5m)',
                                                            label='rechtdoor + Links + Rechts (5m)',
                                                            status='ingebruik',
                                                            definitie='Pijl Rechtdoor + Links + Rechts (5m)',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-+-Links-+-Rechts-(5m)'),
        'rechtdoor-+-Links-+-Rechts-(7.5m)': KeuzelijstWaarde(invulwaarde='rechtdoor-+-Links-+-Rechts-(7.5m)',
                                                              label='rechtdoor + Links + Rechts (7.5m)',
                                                              status='ingebruik',
                                                              definitie='Pijl Rechtdoor + Links + Rechts (7,5m)',
                                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-+-Links-+-Rechts-(7.5m)'),
        'rechtdoor-+-Rechts-(5m)': KeuzelijstWaarde(invulwaarde='rechtdoor-+-Rechts-(5m)',
                                                    label='rechtdoor + Rechts (5m)',
                                                    status='ingebruik',
                                                    definitie='Pijl Rechtdoor + Rechts (5m)',
                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-+-Rechts-(5m)'),
        'rechtdoor-+-Rechts-(7.5m)': KeuzelijstWaarde(invulwaarde='rechtdoor-+-Rechts-(7.5m)',
                                                      label='rechtdoor + Rechts (7.5m)',
                                                      status='ingebruik',
                                                      definitie='Pijl Rechtdoor + Rechts (7,5m)',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-+-Rechts-(7.5m)'),
        'rechtdoor-7-5m': KeuzelijstWaarde(invulwaarde='rechtdoor-7-5m',
                                           label='rechtdoor (7.5m)',
                                           status='ingebruik',
                                           definitie='Pijl Rechtdoor (7.5m)',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechtdoor-7-5m'),
        'rechts-(5m)': KeuzelijstWaarde(invulwaarde='rechts-(5m)',
                                        label='rechts (5m)',
                                        status='ingebruik',
                                        definitie='Pijl Rechts (5m)',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechts-(5m)'),
        'rechts-(7.5m)': KeuzelijstWaarde(invulwaarde='rechts-(7.5m)',
                                          label='rechts (7.5m)',
                                          status='ingebruik',
                                          definitie='Pijl Rechts (7,5m)',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rechts-(7.5m)'),
        'rijstrook-vermindering-links': KeuzelijstWaarde(invulwaarde='rijstrook-vermindering-links',
                                                         label='rijstrook vermindering links',
                                                         status='ingebruik',
                                                         definitie='Pijl Rijstrook vermindering links',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rijstrook-vermindering-links'),
        'rijstrook-vermindering-rechts': KeuzelijstWaarde(invulwaarde='rijstrook-vermindering-rechts',
                                                          label='rijstrook vermindering rechts',
                                                          status='ingebruik',
                                                          definitie='Pijl Rijstrook vermindering rechts',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/rijstrook-vermindering-rechts'),
        'schoolkinderen': KeuzelijstWaarde(invulwaarde='schoolkinderen',
                                           label='schoolkinderen',
                                           status='ingebruik',
                                           definitie='Verkeersbordmarkering schoolkinderen.',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/schoolkinderen'),
        'turborotonde-Links': KeuzelijstWaarde(invulwaarde='turborotonde-Links',
                                               label='turborotonde Links',
                                               status='ingebruik',
                                               definitie='Pijl Turborotonde Links',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/turborotonde-Links'),
        'turborotonde-Rechtdoor': KeuzelijstWaarde(invulwaarde='turborotonde-Rechtdoor',
                                                   label='turborotonde Rechtdoor',
                                                   status='ingebruik',
                                                   definitie='Pijl Turborotonde Rechtdoor',
                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/turborotonde-Rechtdoor'),
        'turborotonde-Rechtdoor-en-Links': KeuzelijstWaarde(invulwaarde='turborotonde-Rechtdoor-en-Links',
                                                            label='turborotonde Rechtdoor en Links',
                                                            status='ingebruik',
                                                            definitie='Pijl Turborotonde Rechtdoor en Links',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/turborotonde-Rechtdoor-en-Links'),
        'turborotonde-Rechtdoor-en-Rechts': KeuzelijstWaarde(invulwaarde='turborotonde-Rechtdoor-en-Rechts',
                                                             label='turborotonde Rechtdoor en Rechts',
                                                             status='ingebruik',
                                                             definitie='Pijl Turborotonde Rechtdoor en Rechts',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/turborotonde-Rechtdoor-en-Rechts'),
        'turborotonde-Rechtdoor.-Links-en-rechts': KeuzelijstWaarde(invulwaarde='turborotonde-Rechtdoor.-Links-en-rechts',
                                                                    label='turborotonde Rechtdoor. Links en rechts',
                                                                    status='ingebruik',
                                                                    definitie='Pijl Turborotonde Rechtdoor, Links en rechts',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/turborotonde-Rechtdoor.-Links-en-rechts'),
        'turborotonde-Rechts': KeuzelijstWaarde(invulwaarde='turborotonde-Rechts',
                                                label='turborotonde Rechts',
                                                status='ingebruik',
                                                definitie='Pijl Turborotonde Rechts',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/turborotonde-Rechts'),
        'voorsortering-Links-(5m)': KeuzelijstWaarde(invulwaarde='voorsortering-Links-(5m)',
                                                     label='voorsortering Links (5m)',
                                                     status='ingebruik',
                                                     definitie='Pijl Voorsortering Links (5m)',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/voorsortering-Links-(5m)'),
        'voorsortering-Links-(7.5m)': KeuzelijstWaarde(invulwaarde='voorsortering-Links-(7.5m)',
                                                       label='voorsortering Links (7.5m)',
                                                       status='ingebruik',
                                                       definitie='Pijl Voorsortering Links (7,5m)',
                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/voorsortering-Links-(7.5m)'),
        'voorsortering-Rechts-(5m)': KeuzelijstWaarde(invulwaarde='voorsortering-Rechts-(5m)',
                                                      label='voorsortering Rechts (5m)',
                                                      status='ingebruik',
                                                      definitie='Pijl Voorsortering Rechts (5m)',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/voorsortering-Rechts-(5m)'),
        'voorsortering-Rechts-(7.5m)': KeuzelijstWaarde(invulwaarde='voorsortering-Rechts-(7.5m)',
                                                        label='voorsortering Rechts (7.5m)',
                                                        status='ingebruik',
                                                        definitie='Aanduiding A49 kruising van een openbare weg door één of meer in de rijbaan aangelegde sporen.',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/voorsortering-Rechts-(7.5m)'),
        'woon-werkverkeer': KeuzelijstWaarde(invulwaarde='woon-werkverkeer',
                                             label='woon-werkverkeer',
                                             status='ingebruik',
                                             definitie='Symbool woon-werkverkeer.',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlFiguratieType/woon-werkverkeer')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDunneOverlagingType(KeuzelijstField):
    """Types van dunne overlaging."""
    naam = 'KlDunneOverlagingType'
    label = 'Dunne overlaging type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDunneOverlagingType'
    definition = 'Types van dunne overlaging.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDunneOverlagingType'
    options = {
        'SME-D1': KeuzelijstWaarde(invulwaarde='SME-D1',
                                   label='SME-D1',
                                   status='ingebruik',
                                   definitie='SME-D1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/SME-D1'),
        'SME-D2': KeuzelijstWaarde(invulwaarde='SME-D2',
                                   label='SME-D2',
                                   status='ingebruik',
                                   definitie='SME-D2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/SME-D2'),
        'antisliplaag': KeuzelijstWaarde(invulwaarde='antisliplaag',
                                         label='antisliplaag',
                                         status='ingebruik',
                                         definitie='antisliplaag',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/antisliplaag'),
        'waterdichte-toplaag-met-instrooi-ng': KeuzelijstWaarde(invulwaarde='waterdichte-toplaag-met-instrooi-ng',
                                                                label='waterdichte toplaag met instrooiïng',
                                                                status='ingebruik',
                                                                definitie='De waterdichte toplaag is een meerlaags vloeibaar aangebracht systeem om de drager (beton, staal, ...) te beschermen tegen waterinfiltratie waarbij de 2de laag wordt ingestrooid met instrooimateriaal om stroefheid te verkrijgen.',
                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/waterdichte-toplaag-met-instrooi-ng'),
        'waterdichte-toplaag-zonder-instrooi-ng': KeuzelijstWaarde(invulwaarde='waterdichte-toplaag-zonder-instrooi-ng',
                                                                   label='waterdichte toplaag zonder instrooiïng',
                                                                   status='ingebruik',
                                                                   definitie='De waterdichte toplaag is een meerlaags vloeibaar aangebracht systeem om de drager (beton, staal, ...) te beschermen tegen waterinfiltratie.',
                                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDunneOverlagingType/waterdichte-toplaag-zonder-instrooi-ng')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ..Datatypes.KlKrimpvoegvulling import KlKrimpvoegvulling


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcKrimpvoegvullingWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._krimpvoegvulling = OTLAttribuut(field=KlKrimpvoegvulling,
                                              naam='krimpvoegvulling',
                                              label='krimvoegvulling',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKrimpvoegvulling.krimpvoegvulling',
                                              definition='De gebruikte vulling van de krimpvoeg.',
                                              owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKrimpvoegvulling.technischeFiche',
                                             definition='De technische fiche van het product waarmee de krimpvoeg is gevuld.',
                                             owner=self)

    @property
    def krimpvoegvulling(self) -> str:
        """De gebruikte vulling van de krimpvoeg."""
        return self._krimpvoegvulling.get_waarde()

    @krimpvoegvulling.setter
    def krimpvoegvulling(self, value):
        self._krimpvoegvulling.set_waarde(value, owner=self._parent)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van het product waarmee de krimpvoeg is gevuld."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcKrimpvoegvulling(ComplexField):
    """Complex datatype om de vulling voor de krimpvoeg aan te duiden met zijn technische fiche."""
    naam = 'DtcKrimpvoegvulling'
    label = 'Krimvoegvulling'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcKrimpvoegvulling'
    definition = 'Complex datatype om de vulling voor de krimpvoeg aan te duiden met zijn technische fiche.'
    waardeObject = DtcKrimpvoegvullingWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPTRegelaarModuleMerk(KeuzelijstField):
    """Keuzelijst met merknamen voor PTRegelaarModule."""
    naam = 'KlPTRegelaarModuleMerk'
    label = 'PT regelaarmodule merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlPTRegelaarModuleMerk'
    definition = 'Keuzelijst met merknamen voor PTRegelaarModule.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPTRegelaarModuleMerk'
    options = {
        'adeunis': KeuzelijstWaarde(invulwaarde='adeunis',
                                    label='Adeunis',
                                    status='ingebruik',
                                    definitie='Adeunis',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPTRegelaarModuleMerk/adeunis'),
        'moxa': KeuzelijstWaarde(invulwaarde='moxa',
                                 label='Moxa',
                                 status='ingebruik',
                                 definitie='Moxa',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPTRegelaarModuleMerk/moxa'),
        'puls': KeuzelijstWaarde(invulwaarde='puls',
                                 label='Puls',
                                 status='ingebruik',
                                 definitie='Puls',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPTRegelaarModuleMerk/puls'),
        'spie': KeuzelijstWaarde(invulwaarde='spie',
                                 label='Spie',
                                 status='ingebruik',
                                 definitie='Spie',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPTRegelaarModuleMerk/spie')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BegroeidVoorkomen import BegroeidVoorkomen
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Grindgazon(BegroeidVoorkomen, VlakGeometrie):
    """Gazontype specifiek op een gestabiliseerde ondergrond. Het is een substraat ontwikkeld om voertuigen sporadisch toe te laten op gazons zonder dat er spoorvorming optreedt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grindgazon'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._isTweelaags = OTLAttribuut(field=BooleanField,
                                         naam='isTweelaags',
                                         label='is tweelaags',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grindgazon.isTweelaags',
                                         definition='Geeft aan of het grindgazon tweelaags of éénlaags is.',
                                         owner=self)

    @property
    def isTweelaags(self) -> bool:
        """Geeft aan of het grindgazon tweelaags of éénlaags is."""
        return self._isTweelaags.get_waarde()

    @isTweelaags.setter
    def isTweelaags(self, value):
        self._isTweelaags.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSeinbrugRijrichting(KeuzelijstField):
    """Mogelijke rijrichtingen bij een seinbrug (enkele of dubbele)."""
    naam = 'KlSeinbrugRijrichting'
    label = 'Seinbrug rijrichting'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSeinbrugRijrichting'
    definition = 'Mogelijke rijrichtingen bij een seinbrug (enkele of dubbele).'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSeinbrugRijrichting'
    options = {
        'dubbele-rijrichting': KeuzelijstWaarde(invulwaarde='dubbele-rijrichting',
                                                label='dubbele rijrichting',
                                                status='ingebruik',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSeinbrugRijrichting/dubbele-rijrichting'),
        'enkele-rijrichting': KeuzelijstWaarde(invulwaarde='enkele-rijrichting',
                                               label='enkele rijrichting',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSeinbrugRijrichting/enkele-rijrichting')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlClusterClusterdoel import KlClusterClusterdoel
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Cluster(AIMNaamObject, PuntGeometrie):
    """Groep van servers die samenwerken om een gemeenschappelijk doel te bereiken (zowel voor groeperen van resources en/of redundantie)."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cluster'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hardware', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VirtueleServer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsSWGehostOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VirtueleServer', direction='i')  # i = direction: incoming

        self._clusterdoel = OTLAttribuut(field=KlClusterClusterdoel,
                                         naam='clusterdoel',
                                         label='clusterdoel',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cluster.clusterdoel',
                                         definition='De reden waarom de custer is opgezet, bv. resources groeperen of redundantie.',
                                         owner=self)

    @property
    def clusterdoel(self) -> str:
        """De reden waarom de custer is opgezet, bv. resources groeperen of redundantie."""
        return self._clusterdoel.get_waarde()

    @clusterdoel.setter
    def clusterdoel(self, value):
        self._clusterdoel.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Geleiding import Geleiding
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlGeleidingMateriaal import KlGeleidingMateriaal
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Geleidingswand(Geleiding, LijnGeometrie):
    """Een geleidingswand geleidt kleinere dieren zoals amfibieën naar kleinere ecokokers,ecoduikers en dergelijke."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleidingswand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ecoraster', direction='u')  # u = unidirectional

        self._hoogte = OTLAttribuut(field=KwantWrdInMillimeter,
                                    naam='hoogte',
                                    label='hoogte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleidingswand.hoogte',
                                    definition='De hoogte van de geleidingswand in millimeter.',
                                    owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleidingswand.lengte',
                                    definition='De lengte van de geleidingswand in meter.',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlGeleidingMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleidingswand.materiaal',
                                       definition='Het materiaal van de geleiding.',
                                       owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geleidingswand.technischeFiche',
                                             definition='De technische fiche van de geleidingswand.',
                                             owner=self)

    @property
    def hoogte(self) -> KwantWrdInMillimeterWaarden:
        """De hoogte van de geleidingswand in millimeter."""
        return self._hoogte.get_waarde()

    @hoogte.setter
    def hoogte(self, value):
        self._hoogte.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van de geleidingswand in meter."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal van de geleiding."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de geleidingswand."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAfdichtingType(KeuzelijstField):
    """De verschillende types afdichtingen."""
    naam = 'KlAfdichtingType'
    label = 'Afdichting type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAfdichtingType'
    definition = 'De verschillende types afdichtingen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAfdichtingType'
    options = {
        'gietasfalt': KeuzelijstWaarde(invulwaarde='gietasfalt',
                                       label='gietasfalt',
                                       status='ingebruik',
                                       definitie='Gietasfalt is een soort asfalt die door zijn overmaat aan bitumen in het mengsel van stenen, zand, vulstof en bitumen zijn waterdichte en dampdichte eigenschap verkrijgt.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingType/gietasfalt'),
        'hars': KeuzelijstWaarde(invulwaarde='hars',
                                 label='hars',
                                 status='ingebruik',
                                 definitie='Hars is een organische vaste of half-vloeibare, vaak kleverige verbinding die meestal lichtgeel en doorschijnend is, onoplosbare is in water, geen of weinig neiging heeft tot kristalliseren, mogelijk kan gaan vloeien als het aan spanningen wordt onderworpen.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingType/hars'),
        'membraan': KeuzelijstWaarde(invulwaarde='membraan',
                                     label='membraan',
                                     status='ingebruik',
                                     definitie='Een membraan of vlies is een dunne, vlakke structuur die twee ruimtes van elkaar scheidt.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAfdichtingType/membraan')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Abstracten.Geleidingsmechanisme import Geleidingsmechanisme
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Scharnierpunt(Geleidingsmechanisme, AIMNaamObject):
    """Een vast draaipunt waar de rotatie van een bewegend onderdeel plaatsvindt rond een as. Het scharnierpunt is samengesteld uit kleinere onderdelen zoals een as, ring, draagstoel, …"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Scharnierpunt'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AsMechanisch', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BusMechanisch', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dichting', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draagstoel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#RingMechanisch', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlSpanningsomvormerModelnaam(KeuzelijstField):
    """Lijst van modelnamen van spanningsomvormers volgens de fabrikant."""
    naam = 'KlSpanningsomvormerModelnaam'
    label = 'Modelnamen spanningsomvormers'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlSpanningsomvormerModelnaam'
    definition = 'Lijst van modelnamen van spanningsomvormers volgens de fabrikant.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlSpanningsomvormerModelnaam'
    options = {
        'cp10-241': KeuzelijstWaarde(invulwaarde='cp10-241',
                                     label='CP10.241',
                                     status='ingebruik',
                                     definitie='CP10.241',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSpanningsomvormerModelnaam/cp10-241'),
        'cp5-241': KeuzelijstWaarde(invulwaarde='cp5-241',
                                    label='CP5.241',
                                    status='ingebruik',
                                    definitie='CP5.241',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSpanningsomvormerModelnaam/cp5-241'),
        'minipack': KeuzelijstWaarde(invulwaarde='minipack',
                                     label='Minipack',
                                     status='ingebruik',
                                     definitie='Minipack',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSpanningsomvormerModelnaam/minipack'),
        'qs10-241': KeuzelijstWaarde(invulwaarde='qs10-241',
                                     label='QS10.241',
                                     status='ingebruik',
                                     definitie='QS10.241',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSpanningsomvormerModelnaam/qs10-241'),
        'qs5-241': KeuzelijstWaarde(invulwaarde='qs5-241',
                                    label='QS5.241',
                                    status='ingebruik',
                                    definitie='QS5.241',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSpanningsomvormerModelnaam/qs5-241'),
        'smartpack-s': KeuzelijstWaarde(invulwaarde='smartpack-s',
                                        label='Smartpack S ',
                                        status='ingebruik',
                                        definitie='Smartpack S ',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSpanningsomvormerModelnaam/smartpack-s'),
        'trio': KeuzelijstWaarde(invulwaarde='trio',
                                 label='Trio',
                                 status='ingebruik',
                                 definitie='Trio',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlSpanningsomvormerModelnaam/trio')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlAansluitingMIVMeetpunt(KeuzelijstField):
    """De aansluiting van de meetlussen op het verwerkingssysteem."""
    naam = 'KlAansluitingMIVMeetpunt'
    label = 'aansluiting meetlussen'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlAansluitingMIVMeetpunt'
    definition = 'De aansluiting van de meetlussen op het verwerkingssysteem.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlAansluitingMIVMeetpunt'
    options = {
        'edv': KeuzelijstWaarde(invulwaarde='edv',
                                label='EDV',
                                status='ingebruik',
                                definitie=' EDV',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingMIVMeetpunt/edv'),
        'rechtstreeks': KeuzelijstWaarde(invulwaarde='rechtstreeks',
                                         label='Rechtstreeks',
                                         status='ingebruik',
                                         definitie='Rechtstreeks',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingMIVMeetpunt/rechtstreeks'),
        'uxl': KeuzelijstWaarde(invulwaarde='uxl',
                                label='UXL',
                                status='ingebruik',
                                definitie='UXL',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlAansluitingMIVMeetpunt/uxl')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkpoortType(KeuzelijstField):
    """Lijst van types voor Netwerkpoort."""
    naam = 'KlNetwerkpoortType'
    label = 'Netwerkpoort type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkpoortType'
    definition = 'Lijst van types voor Netwerkpoort.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkpoortType'
    options = {
        'NNI': KeuzelijstWaarde(invulwaarde='NNI',
                                label='NNI',
                                status='ingebruik',
                                definitie='Network-Network-Interface: deze poort verbindt het netwerk toestel met een ander netwerk toestel binnen eenzelfde netwerk technologie',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortType/NNI'),
        'NULL': KeuzelijstWaarde(invulwaarde='NULL',
                                 label='NULL',
                                 status='ingebruik',
                                 definitie='Geen interface.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortType/NULL'),
        'Other': KeuzelijstWaarde(invulwaarde='Other',
                                  label='Other',
                                  status='ingebruik',
                                  definitie='Ander, onbekend type interface. Deze optie mag uitsluitend TIJDELIJK worden gebruikt en enkel tot de juiste gegevens beschikbaar zijn. Misbruik van deze optie leidt tot verminderde datakwaliteit.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortType/Other'),
        'UNI': KeuzelijstWaarde(invulwaarde='UNI',
                                label='UNI',
                                status='ingebruik',
                                definitie='User-Network-Interface: deze poort verbindt het netwerk toestel direct met de poort van een gebruiker',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortType/UNI'),
        'e-nni': KeuzelijstWaarde(invulwaarde='e-nni',
                                  label='e-NNI',
                                  status='ingebruik',
                                  definitie='External Network-Network-Interface: deze poort verbindt het netwerk toestel met een ander netwerk toestel van een andere netwerk technologie',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortType/e-nni'),
        'i-uni': KeuzelijstWaarde(invulwaarde='i-uni',
                                  label='i-UNI',
                                  status='ingebruik',
                                  definitie='Internal User-Network-Interface: deze poort verbindt het netwerk toestel via een link met de poort van een gebruiker.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortType/i-uni'),
        'ncni': KeuzelijstWaarde(invulwaarde='ncni',
                                 label='NCNI',
                                 status='ingebruik',
                                 definitie='Een Not Configured Network Interface.',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkpoortType/ncni')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from abc import abstractmethod
from ...Classes.Abstracten.Signalisatie import Signalisatie
from ...Classes.ImplementatieElement.AIMObject import AIMObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Straatmeubilair(Signalisatie, AIMObject):
    """Abstracte bedoeld om het straatmeubilair onder 1 noemer te houden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Straatmeubilair'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AndereVerharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ArtificieleLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Bestrating', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LaagBouwklasse', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afdichting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Asfaltmat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BeschermingWapening', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Beschermlaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetonstraatsteen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanBetontegel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanGebakkenStraatsteen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanGrasbetontegel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanKassei', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanMozaiekkei', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BestratingVanNatuursteentegel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bestrijking', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Betonmat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Betonmatras', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BitumineuzeLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cementbetonverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ColloidaalBeton', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dolomietverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Draineerlaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeexpandeerdPolystyreen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Geotextiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grond', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Noppendrainage', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OnbegroeidVoorkomen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderbouw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schanskorf', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ScheurremmendeLaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slemlaag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Steenslagverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stortdraad', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stortsteen', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ternairmengselverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerhardingGrasKunststofplaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Walsbetonverharding', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WaterdoorlatendeBestrating', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wiepenmat', direction='u')  # u = unidirectional



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlEcoBoombrugType(KeuzelijstField):
    """Types van boombrug."""
    naam = 'KlEcoBoombrugType'
    label = 'Boombrug type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlEcoBoombrugType'
    definition = 'Types van boombrug.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlEcoBoombrugType'
    options = {
        'ladderbrug': KeuzelijstWaarde(invulwaarde='ladderbrug',
                                       label='ladderbrug',
                                       status='ingebruik',
                                       definitie='Een boombrug waarbij de oversteek bestaat uit een laddervorm gemaakt uit touw (touwladder) of metaal-kunststof (kabelnet) of een weefsel van takken en nylon (Takkenmat).',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoBoombrugType/ladderbrug'),
        'portaal-boomgoot': KeuzelijstWaarde(invulwaarde='portaal-boomgoot',
                                             label='portaal boomgoot',
                                             status='ingebruik',
                                             definitie='Een bestaande portaal voor signalisatie ingericht als boomrug door middel van een aluminium ladder of houten loopplank of goot.',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoBoombrugType/portaal-boomgoot'),
        'touwbrug': KeuzelijstWaarde(invulwaarde='touwbrug',
                                     label='touwbrug',
                                     status='ingebruik',
                                     definitie='Een boombrug bestaande uit een gedraaid touw van natuurlijke of kunstmatige vezels, dat strak over de weg wordt gespannen en voldoende dik is om er dieren op een stabiele wijze overheen te laten lopen.',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoBoombrugType/touwbrug'),
        'tunnelbrug': KeuzelijstWaarde(invulwaarde='tunnelbrug',
                                       label='tunnelbrug',
                                       status='ingebruik',
                                       definitie='Een boombrug bestaande uit een tunnelvormige oversteek gemaakt uit geweven touwen (touwtunnel) of een buisvormige draadkoker (kokerbrug)',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlEcoBoombrugType/tunnelbrug')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlDetectieVeMerk(KeuzelijstField):
    """De mogelijke opties voor het merk van een detectieverwerkingseenheid."""
    naam = 'KlDetectieVeMerk'
    label = 'Detectieverwerkingseenheid merk'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlDetectieVeMerk'
    definition = 'De mogelijke opties voor het merk van een detectieverwerkingseenheid.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlDetectieVeMerk'
    options = {
        'flir': KeuzelijstWaarde(invulwaarde='flir',
                                 label='FLIR',
                                 status='ingebruik',
                                 definitie='FLIR',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlDetectieVeMerk/flir')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlZijdenType(KeuzelijstField):
    """Het type van de zijden."""
    naam = 'KlZijdenType'
    label = 'Zijden type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlZijdenType'
    definition = 'Het type van de zijden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlZijdenType'
    options = {
        'gebogen': KeuzelijstWaarde(invulwaarde='gebogen',
                                    label='Gebogen',
                                    status='ingebruik',
                                    definitie='Gebogen zijden.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZijdenType/gebogen'),
        'rechte': KeuzelijstWaarde(invulwaarde='rechte',
                                   label='Rechte',
                                   status='ingebruik',
                                   definitie='Rechte zijden.',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZijdenType/rechte'),
        'rechte-en-schuine': KeuzelijstWaarde(invulwaarde='rechte-en-schuine',
                                              label='Rechte en schuine',
                                              status='ingebruik',
                                              definitie='Rechte en schuine zijden gecombineerd.',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZijdenType/rechte-en-schuine'),
        'ronde': KeuzelijstWaarde(invulwaarde='ronde',
                                  label='Ronde',
                                  status='ingebruik',
                                  definitie='Ronde zijden.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZijdenType/ronde'),
        'schuine': KeuzelijstWaarde(invulwaarde='schuine',
                                    label='Schuine',
                                    status='ingebruik',
                                    definitie='Schuine zijden.',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlZijdenType/schuine')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMeetcelNauwkeurigheidsvermogen(KeuzelijstField):
    """Nauwkeurigheidsvermogen van de meetcel in voltampère (bv. 5 of 15)."""
    naam = 'KlMeetcelNauwkeurigheidsvermogen'
    label = 'Meetcel nauwkeurigheidsvermogen'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMeetcelNauwkeurigheidsvermogen'
    definition = 'Nauwkeurigheidsvermogen van de meetcel in voltampère (bv. 5 of 15).'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMeetcelNauwkeurigheidsvermogen'
    options = {
        '15': KeuzelijstWaarde(invulwaarde='15',
                               label='15',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMeetcelNauwkeurigheidsvermogen/15'),
        '5': KeuzelijstWaarde(invulwaarde='5',
                              label='5',
                              status='ingebruik',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMeetcelNauwkeurigheidsvermogen/5')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkelemGebruik(KeuzelijstField):
    """Keuzelijst met de verschillende mogelijke netwerkstructuren waarbinnen een netwerkelement kan ingezet worden."""
    naam = 'KlNetwerkelemGebruik'
    label = 'Netwerkelement gebruik'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkelemGebruik'
    definition = 'Keuzelijst met de verschillende mogelijke netwerkstructuren waarbinnen een netwerkelement kan ingezet worden.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkelemGebruik'
    options = {
        '4g-wireless-router': KeuzelijstWaarde(invulwaarde='4g-wireless-router',
                                               label='4G wireless router',
                                               status='ingebruik',
                                               definitie='Het netwerkelement wordt gebruikt binnen een 4G draadloos netwerk.',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/4g-wireless-router'),
        '4g-wireless-router-dsl-backup': KeuzelijstWaarde(invulwaarde='4g-wireless-router-dsl-backup',
                                                          label='4G wireless router - DSL backup',
                                                          status='ingebruik',
                                                          definitie='Het netwerkelement wordt gebruikt binnen een 4G draadloos netwerk. DSL wordt gebruikt als backup bij faling van het 4G draadloos netwerk.',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/4g-wireless-router-dsl-backup'),
        'cen': KeuzelijstWaarde(invulwaarde='cen',
                                label='CEN',
                                status='ingebruik',
                                definitie='Het netwerkelement wordt gebruikt binnen het CEN netwerk.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/cen'),
        'dsl-router': KeuzelijstWaarde(invulwaarde='dsl-router',
                                       label='DSL  router',
                                       status='ingebruik',
                                       definitie='Het netwerkelement wordt gebruikt binnen een DSL netwerk.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/dsl-router'),
        'dsl-router-4g-wireless-backup': KeuzelijstWaarde(invulwaarde='dsl-router-4g-wireless-backup',
                                                          label='DSL router - 4G wireless backup',
                                                          status='ingebruik',
                                                          definitie='Het netwerkelement wordt gebruikt binnen een DSL netwerk. Een 4G  wordt gebruikt als backup bij faling van het DSL netwerk.',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/dsl-router-4g-wireless-backup'),
        'hdsl-modem': KeuzelijstWaarde(invulwaarde='hdsl-modem',
                                       label='HDSL-modem',
                                       status='ingebruik',
                                       definitie='Een HDSL modem.',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/hdsl-modem'),
        'l2-switch': KeuzelijstWaarde(invulwaarde='l2-switch',
                                      label='L2-switch',
                                      status='ingebruik',
                                      definitie='Het netwerkelement wordt gebruikt binnen de L2 netwerkstructuur.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/l2-switch'),
        'l3-switch': KeuzelijstWaarde(invulwaarde='l3-switch',
                                      label='L3-switch',
                                      status='ingebruik',
                                      definitie='Het netwerkelement wordt gebruikt binnen de L3 netwerkstructuur.',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/l3-switch'),
        'otn': KeuzelijstWaarde(invulwaarde='otn',
                                label='OTN',
                                status='ingebruik',
                                definitie='Het netwerkelement wordt gebruikt binnen het optisch transport netwerk.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/otn'),
        'sdh': KeuzelijstWaarde(invulwaarde='sdh',
                                label='SDH',
                                status='ingebruik',
                                definitie='Het netwerkelement wordt gebruikt binnen het SDH netwerk.',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/sdh'),
        'straalverbinding': KeuzelijstWaarde(invulwaarde='straalverbinding',
                                             label='Straalverbinding',
                                             status='ingebruik',
                                             definitie='Straalverbinding',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/straalverbinding'),
        'wifi-access-point': KeuzelijstWaarde(invulwaarde='wifi-access-point',
                                              label='Wifi access point',
                                              status='ingebruik',
                                              definitie='Het netwerkelement is een Wifi access point.',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkelemGebruik/wifi-access-point')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod, ABC
from ...Datatypes.DtcProductidentificatiecode import DtcProductidentificatiecode, DtcProductidentificatiecodeWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class LaagProductidentificatiecode(ABC):
    """Abstracte waarmee aan een laag de eigenschap productidentificatiecode wordt toegekend."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LaagProductidentificatiecode'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._productidentificatiecode = OTLAttribuut(field=DtcProductidentificatiecode,
                                                      naam='productidentificatiecode',
                                                      label='productidentificatiecode',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LaagProductidentificatiecode.productidentificatiecode',
                                                      definition='De productidentificatiecode van het gebruikte product (bv. COPRO code of Benor code).',
                                                      owner=self)

    @property
    def productidentificatiecode(self) -> DtcProductidentificatiecodeWaarden:
        """De productidentificatiecode van het gebruikte product (bv. COPRO code of Benor code)."""
        return self._productidentificatiecode.get_waarde()

    @productidentificatiecode.setter
    def productidentificatiecode(self, value):
        self._productidentificatiecode.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlTypeGrendel import KlTypeGrendel
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Grendel(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een mechanisch onderdeel dat toelaat om een constructie of bewegend element in een gewenste positie te vergrendelen, meestal door middel van een schuif-, klem- of draaibeweging. """

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grendel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Grendelmechanisme', direction='o')  # o = direction: outgoing

        self._typeGrendel = OTLAttribuut(field=KlTypeGrendel,
                                         naam='typeGrendel',
                                         label='type grendel',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grendel.typeGrendel',
                                         definition='Het type grendel.',
                                         owner=self)

    @property
    def typeGrendel(self) -> str:
        """Het type grendel."""
        return self._typeGrendel.get_waarde()

    @typeGrendel.setter
    def typeGrendel(self, value):
        self._typeGrendel.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod
from ...Classes.Abstracten.Geleiding import Geleiding


# Generated with OTLClassCreator. To modify: extend, do not edit
class ComplexeGeleiding(Geleiding):
    """Een Abstracte die de SluitAanOp relatie mogelijk maakt voor de samenstellende onderdelen van een complexere geleiding."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfmetingenDiepCBWand', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BalkGK', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Betonfundering', direction='o', deprecated='2.0.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructiefObject', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#DamplankAbstracte', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KlassiekeFundering', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Aanslagbalk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balans', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balansarm', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#BeweegbareWaterkerendeConstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Boog', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Breekbalk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Damwand', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DraagstructuurBWCTWC', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gewelf', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gording', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameipoort', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hameistijl', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hefportiek', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Heftoren', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#HorizontaleConstructieplaat', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kabelkoker', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kolom', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koppelbalk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MVPaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pyloon', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Randprofiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#StalenFunderingsprofiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Tegengewichtkist', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#TijdelijkeWaterkerendeConstructie', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#VakwerkElement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Verdeelbalk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wand', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Windverband', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Wrijfbalk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Baret', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenBoorpaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenDamplank', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenHeipaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenPlaat', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenPredal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenProfiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenSchroefpaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Breedplaat', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CFAPaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#CementBentonietwand', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#ConstructieSokkel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Damwand', direction='o', deprecated='2.8.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Diepwand', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Druklaag', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EcoPoort', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ecoraster', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#FunderingOpStaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingsmassief', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingspaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingsplaat', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingsput', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingszool', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grindkern', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Groutpaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenConstructieprofiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenDamplank', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoutenHeipaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Injectiepaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KunststoffenDamplank', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Metselwerk', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Micropaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NietStandaardStalenProfiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#PlintGC', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SoilmixwandElement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenBuispaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenDamplank', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenPlaat', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenSchroefpaal', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StandaardStalenProfiel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Terugkeer', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Veerooster', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verankeringsmassief', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.KlLEKantopsluitingBijkomendeParameter import KlLEKantopsluitingBijkomendeParameter
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcLENormWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._bijkomendeParameter = OTLAttribuut(field=KlLEKantopsluitingBijkomendeParameter,
                                                 naam='bijkomendeParameter',
                                                 label='bijkomende parameter',
                                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcLENorm.bijkomendeParameter',
                                                 definition='Het gedetailleerder typeren van de kantopsluiting.',
                                                 owner=self)

        self._norm = OTLAttribuut(field=StringField,
                                  naam='norm',
                                  label='norm',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcLENorm.norm',
                                  definition='De opgelegde en beschreven standaard van de kantopsluiting.',
                                  owner=self)

    @property
    def bijkomendeParameter(self) -> str:
        """Het gedetailleerder typeren van de kantopsluiting."""
        return self._bijkomendeParameter.get_waarde()

    @bijkomendeParameter.setter
    def bijkomendeParameter(self, value):
        self._bijkomendeParameter.set_waarde(value, owner=self._parent)

    @property
    def norm(self) -> str:
        """De opgelegde en beschreven standaard van de kantopsluiting."""
        return self._norm.get_waarde()

    @norm.setter
    def norm(self, value):
        self._norm.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcLENorm(ComplexField):
    """Complex datatype voor de norm van het lijnvormig element."""
    naam = 'DtcLENorm'
    label = 'Norm van het lijnvormig element'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DtcLENorm'
    definition = 'Complex datatype voor de norm van het lijnvormig element.'
    waardeObject = DtcLENormWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from ...Classes.Abstracten.StaalsoortObject import StaalsoortObject
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Halsbeugelpen(StaalsoortObject, TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een onderdeel van het halsbeugelmechanisme dat is geïntegreerd in de sluisdeur. Deze pen fungeert als draaipunt voor de bewegingen van de deur. Rondom de pen zijn het lagerelement en het halsbeugeloog geplaatst, die de beweging ondersteunen en eventueel reguleren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Halsbeugelpen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Halsbeugelmechanisme', direction='o')  # o = direction: outgoing



# coding=utf-8
from ...Classes.ImplementatieElement.NietDirectioneleRelatie import NietDirectioneleRelatie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Sturing(NietDirectioneleRelatie):
    """Deze relatie geeft aan of er een of andere vorm van dataverkeer is tussen 2 onderdelen. Een wegverlichtingstoestel dat aan staat wordt ook als sturing beschouwd, in dit geval is het een lang ononderbroken elektrisch aan-signaal. Deze relatie heeft geen richting."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
